SystemOrganization addCategory: #'PolySource-Core'!
SystemOrganization addCategory: #'PolySource-Model'!
SystemOrganization addCategory: #'PolySource-Morphic'!
SystemOrganization addCategory: #'PolySource-Network'!
SystemOrganization addCategory: #'PolySource-Tests'!

WorldState subclass: #PSRemoteWorldState
	instanceVariableNames: 'deferredUIMessages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Morphic'!

!PSRemoteWorldState commentStamp: 'mt 9/7/2010 12:14:23.771' prior: 0!
I have my own queue with deferred UI messages. My dynamic scope is changed to the remote client of the corresponding remote world in EVERY update cycle.!

!PSRemoteWorldState methodsFor: 'synchronization' stamp: 'mt 9/7/2010 11:59:35.716'!
addDeferredUIMessage: valuableObject

	self deferredUIMessages nextPut: valuableObject.! !

!PSRemoteWorldState methodsFor: 'synchronization' stamp: 'mt 9/7/2010 11:59:48.829'!
deferredUIMessages

	^ deferredUIMessages ifNil: [deferredUIMessages := SharedQueue new]
! !

!PSRemoteWorldState methodsFor: 'update cycle' stamp: 'mt 9/7/2010 12:12:23.233'!
doOneCycleFor: aRemoteWorld

	PSCurrentRemoteClient
		value: aRemoteWorld remoteClient
		during: [super doOneCycleFor: aRemoteWorld].! !

!PSRemoteWorldState methodsFor: 'stepping' stamp: 'mt 9/7/2010 12:01:24.095'!
runStepMethodsIn: aWorld
	"Perform periodic activity inbetween event cycles"
	| queue msg limit stamp |
	"Limit processing of deferredUIMessages to a max. amount of time"
	limit := self class deferredExecutionTimeLimit.
	stamp := Time millisecondClockValue.
	queue := self deferredUIMessages.
	[(Time millisecondsSince: stamp) >= limit 
		or:[(msg := queue nextOrNil) == nil]] 
			whileFalse: [msg value].
	self runLocalStepMethodsIn: aWorld.! !

SqEntity subclass: #PSSourceCode
	instanceVariableNames: 'uuid snapshot updates categories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Model'!

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/31/2010 10:49:43.319'!
addCategory: aSymbol

	self categories add: aSymbol.
	dummy := #categoryAdded.
	self categoryAdded: aSymbol.! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 13:31:34.438'!
addUpdate: aCodeUpdate

	self updates add: aCodeUpdate.
	dummy := #snapshotUpdated.
	self snapshotUpdated: aCodeUpdate.! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/31/2010 10:48:54.185'!
categories

	^ categories ifNil: [categories := OrderedCollection new]! !

!PSSourceCode methodsFor: 'signals' stamp: 'mt 8/31/2010 10:49:55.775'!
categoryAdded: aSymbol

	self emit.! !

!PSSourceCode methodsFor: 'updating' stamp: 'mt 8/31/2010 11:02:48.477'!
fileInSnapshot
	"Load the source of all categories in the current snapshot into the image."
	
	snapshot keysAndValuesDo: [:category :source | | strm |
		(ReadStream on: source) fileIn].! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 13:26:57.291'!
snapshot

	^ snapshot! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 13:28:08.404'!
snapshot: aCodeSnapshot

	snapshot := aCodeSnapshot.
	self snapshotChanged.! !

!PSSourceCode methodsFor: 'signals' stamp: 'mt 8/30/2010 13:28:01.047'!
snapshotChanged

	self emit.! !

!PSSourceCode methodsFor: 'signals' stamp: 'mt 8/30/2010 13:31:16.622'!
snapshotUpdated: anUpdate

	self emit.! !

!PSSourceCode methodsFor: 'updating' stamp: 'mt 8/31/2010 11:02:25.772'!
updateSnapshot
	"Extract the source code of all registered categories into a dictionary."
	
	| updatedSnapshot |
	updatedSnapshot := Dictionary new.
	
	self categories do: [:cat | | strm |
		strm := WriteStream on: (String new: 100).
		SystemOrganization fileOutCategory: cat on: strm.
		updatedSnapshot at: cat put: strm contents].
	
	self snapshot: updatedSnapshot.
	self snapshotChanged.! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 13:29:16.047'!
updates

	^ updates ifNil: [updates := OrderedCollection new]! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 15:26:59.314'!
uuid

	^ uuid! !

!PSSourceCode methodsFor: 'accessing' stamp: 'mt 8/30/2010 15:27:09.666'!
uuid: aUUID

	uuid := aUUID.! !

SqEntity subclass: #PSSourceCodeRepository
	instanceVariableNames: 'sourceCodes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Model'!

!PSSourceCodeRepository methodsFor: 'add/remove' stamp: 'mt 9/6/2010 11:23:39.632'!
addSourceCode: aSourceCode

	self sourceCodes add: aSourceCode.
	dummy := #sourceCodeAdded.
	^ aSourceCode! !

!PSSourceCodeRepository methodsFor: 'add/remove' stamp: 'mt 9/6/2010 11:24:56.698'!
removeSourceCode: aSourceCode

	self sourceCode remove: aSourceCode ifAbsent: [].
	dummy := #sourceCodeRemoved.
	^ aSourceCode! !

!PSSourceCodeRepository methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:24:32.092'!
sourceCodeByID: aUUID

	^ self sourceCodes
		detect: [:c | c uuid = aUUID]
		ifNone: [self addSourceCode: (PSSourceCode new uuid: aUUID)]! !

!PSSourceCodeRepository methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:23:03.891'!
sourceCodes

	^ sourceCodes ifNil: [sourceCodes := OrderedCollection new]! !

Dictionary subclass: #PSFixtures
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Tests'!

PSFixtures class
	instanceVariableNames: 'instance'!

PSFixtures class
	instanceVariableNames: 'instance'!

!PSFixtures class methodsFor: 'accessing' stamp: 'mig 8/9/2010 17:30:19.665'!
at: key

	^ self instance at: key! !

!PSFixtures class methodsFor: 'accessing' stamp: 'mig 8/9/2010 17:30:01.619'!
at: key put: value
.
	^ self instance at: key put: value! !

!PSFixtures class methodsFor: 'examples' stamp: 'mt 9/6/2010 11:46:25.931'!
example01

	"Need a proxy to get the class compiled into the right dictionary."
	PSSystemDictionaryProxy install.

	PSCurrentRemoteClient
		value: (PSFixtures at: #example01 put: PSRemoteClient new)
		during: [Object
			subclass: #PSFoobar
			instanceVariableNames: ''
			classVariableNames: ''
			poolDictionaries: ''
			category: 'PolySource-Tests-Temporary'].

	"Test data prepared. Clean up."
	Smalltalk globals uninstall.! !

!PSFixtures class methodsFor: 'testing' stamp: 'mig 8/25/2010 13:53:39.589'!
includesKey: key

	^ self instance includesKey: key! !

!PSFixtures class methodsFor: 'singleton' stamp: 'mig 8/9/2010 17:29:05.257'!
instance

	^ instance ifNil: [instance := self new]! !

DynamicVariable subclass: #PSCurrentRemoteClient
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Core'!

PasteUpMorph subclass: #PSRemoteWorld
	instanceVariableNames: 'remoteClient infoLabel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Morphic'!

!PSRemoteWorld commentStamp: 'mt 9/7/2010 12:15:36.029' prior: 0!
A remote world has a remote world state and a remote client. =D!

!PSRemoteWorld class methodsFor: 'project' stamp: 'mt 9/7/2010 12:03:27.714'!
newWorldForProject: projectOrNil 

	^ self new initForProject: PSRemoteWorldState new! !

!PSRemoteWorld methodsFor: 'initialize' stamp: 'mt 9/7/2010 12:30:40.625'!
initialize

	super initialize.
	self
		color: (Color gray: 0.8);
		borderWidth: 0.
		
	infoLabel := TextMorph new.
	self addMorphBack: infoLabel.
	infoLabel topLeft: self topLeft + (20@50).
	
	self connect: self signal: #remoteClient: toSelector: #updateInfoLabel.
	self updateInfoLabel.! !

!PSRemoteWorld methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:26:10.299'!
remoteClient

	^ remoteClient! !

!PSRemoteWorld methodsFor: 'accessing' stamp: 'mt 9/7/2010 12:18:58.166'!
remoteClient: aRemoteClient

	remoteClient := aRemoteClient.! !

!PSRemoteWorld methodsFor: 'initialize' stamp: 'mt 9/7/2010 12:27:41.68'!
updateInfoLabel

	infoLabel contents: 
		(self remoteClient
			ifNil: ['<font size="12" color="#990000"><b>No remote client configured.</b></font>' asHtmlText]
			ifNotNil: ['<font size="12" color="#F0F0F0"><b>Remote client found.</b></font>' asHtmlText]).! !

!SystemOrganizer methodsFor: '*polysource-core' stamp: 'mt 8/30/2010 11:30:34.255'!
isProxy

	^ false! !

SystemDictionary subclass: #PSSystemDictionary
	instanceVariableNames: 'organization'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Core'!

!PSSystemDictionary commentStamp: 'mt 8/29/2010 19:23:48.53' prior: 0!
I am a copy of the local SystemDictionary (Smalltalk globals) but I do not copy the classes. I provide my own organization.!

!PSSystemDictionary methodsFor: 'initialize' stamp: 'mig 8/9/2010 15:00:32.549'!
initialize: size

	super initialize: size.
	Smalltalk globals keysAndValuesDo: [ :key :value |
		self at: key put: value].! !

!SystemDictionary methodsFor: '*polysource-core' stamp: 'mt 8/29/2010 19:32:52.227'!
isProxy

	^ false! !

TestCase subclass: #PSBasicTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Tests'!

!PSBasicTestCase methodsFor: 'tests' stamp: 'mig 8/9/2010 15:22:47.123'!
test01new

	| sut |
	sut := PSSystemDictionary new.

	self assert: sut size equals: Smalltalk globals size.
	Smalltalk globals keysAndValuesDo: [:key :value |
		self assert: value == (sut at: key)].
! !

!PSBasicTestCase methodsFor: 'tests' stamp: 'mig 8/10/2010 13:59:49.758'!
test02proxy

	| testCase sut root |
	
	sut := PSSystemDictionaryProxy new.
	root := Smalltalk globals.
	
	testCase := Smalltalk globals at: #TestCase.
	
	sut install.
	self assert: sut == Smalltalk globals.
	self assert: testCase == (Smalltalk globals at: #TestCase).
	sut uninstall.
	self assert: root == Smalltalk globals.! !

!PSBasicTestCase methodsFor: 'tests' stamp: 'mt 8/30/2010 11:55:22.347'!
test03proxyWithOrganization

	PSSystemDictionaryProxy install.
	
	self
		assert: Smalltalk globals isProxy;
		assert: SystemOrganization isProxy.
		
	PSSystemDictionaryProxy uninstall.
	
	self
		deny: Smalltalk globals isProxy;
		deny: SystemOrganization isProxy.! !

TestCase subclass: #PSModelTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Tests'!

!PSModelTestCase methodsFor: 'tests' stamp: 'mt 9/6/2010 11:21:18.835'!
test01snapshots

	| cc |
	cc := PSSourceCode new.
	cc
		addCategory: #'PolySource-Core';
		addCategory: #'PolySource-Model'.
		
	self assert: cc snapshot isNil.
	
	cc updateSnapshot.
	
	self
		assert: 2 equals: cc snapshot size;
		assert: (cc snapshot includesKey: #'PolySource-Core');
		assert: (cc snapshot includesKey: #'PolySource-Model');
		assert: (cc snapshot associations first value isString).! !

TestCase subclass: #PSNetworkTestCase
	instanceVariableNames: 'srv clt'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Tests'!

!PSNetworkTestCase methodsFor: 'running' stamp: 'mt 9/6/2010 11:10:43.548'!
setUp

	super setUp.
	
	srv := SyServer new start.
	clt := PSLocalClient new
		connection: (SyClient new connectToHostNamed: 'localhost' port: 22701).! !

!PSNetworkTestCase methodsFor: 'running' stamp: 'mt 8/30/2010 15:54:46.481'!
tearDown

	super tearDown.

	clt connection disconnect.

	srv stop.
	srv repository clear.
! !

!PSNetworkTestCase methodsFor: 'tests' stamp: 'mt 9/6/2010 11:21:31.075'!
test01uuid

	| src |
	self assert: clt sourceCode isNil.
	
	clt connection repository rootObject: PSSourceCodeRepository new.
	
	self
		assert: (src := clt sourceCode) notNil;
		assert: clt uuid equals: src uuid.
	
	
! !

TestCase subclass: #PSProxiedTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Tests'!

!PSProxiedTestCase methodsFor: 'running' stamp: 'mt 8/29/2010 19:41:49.115'!
setUp

	super setUp.
	PSSystemDictionaryProxy install.! !

!PSProxiedTestCase methodsFor: 'running' stamp: 'mig 8/10/2010 14:00:41.469'!
tearDown

	Smalltalk globals uninstall.
	super tearDown.
! !

!PSProxiedTestCase methodsFor: 'tests' stamp: 'mt 9/6/2010 11:37:49.751'!
test01environment

	| newRemoteClient |
	newRemoteClient := PSRemoteClient new.
	
	PSCurrentRemoteClient value: newRemoteClient during: [
		self assert: Object environment yourself == newRemoteClient systemDictionary].
	self deny: Object environment yourself == newRemoteClient systemDictionary.
! !

!PSProxiedTestCase methodsFor: 'tests' stamp: 'mt 9/6/2010 11:37:08.187'!
test02newClasses

	self deny: (Smalltalk includesKey: #PSFoobar).
	self deny: (Smalltalk includesKey: #PSFoobar2).
	
	PSCurrentRemoteClient value: PSRemoteClient new during: [
		"Create a class and a subclass of it."
		Object subclass: #PSFoobar instanceVariableNames: '' classVariableNames: '' poolDictionaries: '' category: 'PolySource-Tests-Temporary'.
		(Smalltalk at: #PSFoobar)
			subclass: #PSFoobar2 instanceVariableNames: '' classVariableNames: '' poolDictionaries: '' category: 'PolySource-Tests-Temporary'.
		self assert: (Smalltalk includesKey: #PSFoobar).
		self assert: (Smalltalk includesKey: #PSFoobar2)].
	
	self deny: (Smalltalk includesKey: #PSFoobar).
	self deny: (Smalltalk includesKey: #PSFoobar2).
! !

!PSProxiedTestCase methodsFor: 'tests' stamp: 'mt 9/6/2010 11:36:53.926'!
test03evaluate

	self deny: (Smalltalk includesKey: #PSFoobar).
	
	PSCurrentRemoteClient value: PSRemoteClient new during: [
		"Create a class and instantiate it once."
		Object subclass: #PSFoobar instanceVariableNames: '' classVariableNames: '' poolDictionaries: '' category: 'PolySource-Tests-Temporary'.
		self
			shouldnt: [Compiler evaluate: 'PSFoobar new']
			raise: MessageNotUnderstood].
		
	self
		should: [Compiler evaluate: 'PSFoobar new']
		raise: MessageNotUnderstood.
! !

!PSProxiedTestCase methodsFor: 'tests' stamp: 'mt 8/29/2010 19:56:47.815'!
test05proxyTest

	PSSystemDictionaryProxy uninstall.
	self deny: Smalltalk globals isProxy.

	PSSystemDictionaryProxy install.
	self assert: Smalltalk globals isProxy.! !

Object subclass: #PSLocalClient
	instanceVariableNames: 'uuid connection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Network'!

PSLocalClient class
	instanceVariableNames: 'instance'!

PSLocalClient class
	instanceVariableNames: 'instance'!

!PSLocalClient class methodsFor: 'instance' stamp: 'mt 9/7/2010 10:06:47.765'!
instance
	"This is the instance of PSLocalClient that has to be (re-)used in a normal application. Tests are allowed to create further instances with own SqSync connections and UUIDs."
	
	^ instance ifNil: [instance := self new]! !

!PSLocalClient class methodsFor: 'instance' stamp: 'mt 9/7/2010 10:07:11.685'!
reset
	
	instance := nil.! !

!PSLocalClient methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 15:34:56.859'!
connection

	^ connection! !

!PSLocalClient methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 15:35:10.38'!
connection: anSyClient

	connection := anSyClient.! !

!PSLocalClient methodsFor: 'as yet unclassified' stamp: 'mt 9/7/2010 09:57:06.927'!
remoteClients

	^ self connection rootObject sourceCodes collect: [:sc |
		PSRemoteClient new sourceCode: sc]! !

!PSLocalClient methodsFor: 'as yet unclassified' stamp: 'mt 9/6/2010 11:25:19.911'!
sourceCode

	self connection ifNil: [^ nil].
	self connection repository rootObject ifNil: [^ nil].
	
	^ self connection repository rootObject sourceCodeByID: self uuid! !

!PSLocalClient methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 15:24:04.959'!
uuid

	^ uuid ifNil: [uuid := UUID new]! !

Object subclass: #PSRemoteClient
	instanceVariableNames: 'systemDictionary systemOrganization sourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Network'!

!PSRemoteClient class methodsFor: 'instance creation' stamp: 'mt 9/6/2010 11:17:32.085'!
new

	PSCurrentRemoteClient value ifNotNil: [self signal: 'You have to reset the scope to create a new remote client object!!'].
	^ super new! !

!PSRemoteClient methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:18:05.938'!
initialize

	super initialize.
	
	systemDictionary := PSSystemDictionary new.
	systemOrganization := SystemOrganization deepCopy.! !

!PSRemoteClient methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:34:12.155'!
sourceCode

	^ sourceCode! !

!PSRemoteClient methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:34:20.648'!
sourceCode: aSourceCode

	sourceCode := aSourceCode.! !

!PSRemoteClient methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:18:13.62'!
systemDictionary

	^ systemDictionary! !

!PSRemoteClient methodsFor: 'accessing' stamp: 'mt 9/6/2010 11:18:10.182'!
systemOrganization

	^ systemOrganization! !

MorphicProject subclass: #PSRemoteProject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Morphic'!

!PSRemoteProject commentStamp: 'mt 9/7/2010 12:15:12.813' prior: 0!
A remote projecte has a remote world. ;)!

!PSRemoteProject methodsFor: 'initialize' stamp: 'mt 9/7/2010 10:57:24.923'!
initialize

	self perform: #initialize withArguments: #() inSuperclass: Project.

	world := PSRemoteWorld newWorldForProject: self.
	Locale switchToID: CurrentProject localeID.
	Preferences useVectorVocabulary ifTrue: [world installVectorVocabulary]
	! !

!Class methodsFor: '*polysource-core-override' stamp: 'mig 8/9/2010 16:23:00.596'!
environment

	^ Smalltalk globals
	"environment == nil ifTrue: [^ super environment].
	^ environment"! !

ProtoObject subclass: #PSSystemDictionaryProxy
	instanceVariableNames: 'original'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Core'!

!PSSystemDictionaryProxy class methodsFor: 'installation' stamp: 'mig 8/9/2010 17:42:02.667'!
install

	self new install.! !

!PSSystemDictionaryProxy class methodsFor: 'installation' stamp: 'mig 8/9/2010 17:42:35.209'!
uninstall

	Smalltalk globals uninstall.! !

!PSSystemDictionaryProxy methodsFor: 'proxy' stamp: 'mt 9/6/2010 11:44:05.53'!
doesNotUnderstand: aMessage

	original ifNil: [^ super doesNotUnderstand: aMessage].
	
	^ aMessage sendTo: (PSCurrentRemoteClient value
		ifNil: [original]
		ifNotNil: [PSCurrentRemoteClient value systemDictionary])! !

!PSSystemDictionaryProxy methodsFor: 'installation' stamp: 'mt 8/30/2010 11:49:01.349'!
install

	self isInstalled ifTrue: [^self].

	original := Smalltalk globals.
	Smalltalk instVarNamed: #globals put: self.
	
	"Add a proxy for the organization too."
	PSSystemOrganizerProxy install.
! !

!PSSystemDictionaryProxy methodsFor: 'testing' stamp: 'mig 8/9/2010 15:14:19.08'!
isInstalled

	^ Smalltalk globals == self! !

!PSSystemDictionaryProxy methodsFor: 'testing' stamp: 'mt 8/29/2010 19:32:19.736'!
isProxy

	^ true! !

!PSSystemDictionaryProxy methodsFor: 'installation' stamp: 'mt 8/30/2010 11:49:48.948'!
uninstall

	self isInstalled ifFalse: [^self].

	Smalltalk instVarNamed: #globals put: original.
	original := nil.
	
	"Remove proxy for organization."
	PSSystemOrganizerProxy uninstall.! !

ProtoObject subclass: #PSSystemOrganizerProxy
	instanceVariableNames: 'original'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolySource-Core'!

!PSSystemOrganizerProxy commentStamp: 'mt 8/30/2010 11:52:21.467' prior: 0!
DO NOT install me directly but use "PSSystemDictionaryProxy install" instead.!

!PSSystemOrganizerProxy class methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:37:54.726'!
install

	self new install.! !

!PSSystemOrganizerProxy class methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:38:13.074'!
uninstall

	SystemOrganization uninstall.! !

!PSSystemOrganizerProxy methodsFor: 'as yet unclassified' stamp: 'mt 9/6/2010 11:43:40.372'!
doesNotUnderstand: aMessage

	original ifNil: [^ super doesNotUnderstand: aMessage].
	
	^ aMessage sendTo: (PSCurrentRemoteClient value 
		ifNil: [original]
		ifNotNil: [PSCurrentRemoteClient value systemOrganization])! !

!PSSystemOrganizerProxy methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:37:01.302'!
install

	self isInstalled ifTrue: [^self].

	original := SystemOrganization.
	Smalltalk at: #SystemOrganization put: self.
! !

!PSSystemOrganizerProxy methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:37:27.065'!
isInstalled

	^ SystemOrganization == self! !

!PSSystemOrganizerProxy methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:29:56.853'!
isProxy

	^ true! !

!PSSystemOrganizerProxy methodsFor: 'as yet unclassified' stamp: 'mt 8/30/2010 11:37:15.148'!
uninstall

	self isInstalled ifFalse: [^self].
	
	Smalltalk at: #SystemOrganization put: original.
	original := nil.! !
